sizhi模块by:pianshilengyubing（xiaohuangya）

项目描述：
1.作用：
此模块用来获取地图省市县乡镇四级行政区划的四至点位，默认左上右下，经度在前，纬度在后，请按该顺序编写代码。
利用该模块，可以省去爬虫等工作时需要手动获取四至点位并转换坐标系的过程，便于节省代码，批量使用，还可使得代码更为可控。
有获取行政区划的四至点位（包含全部区划的最小矩形即包络矩形）与自行输入俩种方式。
1.6版本返回为字典
2.0删除了api请求，全部更改为本地数据，并增加了乡镇级的四至获取。

2.使用：
有获取行政区划的四至点位与自行输入俩种方式。
①按行政区划输入：
	需要下载的行政区划中文，请务必加上市、区、县、乡、镇、街道后缀。可输入省市县，以及乡镇街道。eg:北京市、东城区、石门街镇、北王力乡、荷花街道。
	通过区划获取，只对中国城市有效。如果区划有变动，需要手动更新dic。
②自行输入：
	自行在百度坐标拾取系统（http://api.map.baidu.com/lbsapi/getpoint/index.html）上拾取点位，左上右下，按提示输入。

无论通过哪种方式输入均会提示选择后续代码的坐标系，坐标基于百度地图请输入1，高德腾讯地图请输入2，无偏移地图请输入3。其中1输出坐标系为bd09，2输出坐标系为gcj02，3输出坐标系为wgs84.

3.示例：
import sizhi
sizhi=sizhi.sizhi()
........
........
返回值：['北京市', [[115.42984813547287, 41.06702959551089], [117.5210935092895, 39.448668299439845]]]
左上右下，俩个点位的经纬度列表，

